===============================
community.fortios Release Notes
===============================

.. contents:: Topics


v1.0.0
======

Release Summary
---------------

This is the first stable release version of ``community.fortios`` after migrating from ``community.network``.

v0.1.0
======

Release Summary
---------------

This is the first pre-release version of ``community.fortios`` after migrating from ``community.network``.

